/*--------------------------Pulses_095_prime.c  -----------------------------------
 * 
 * 19.06.2020
 * 
 * Getestet auf ATMega 328p mit 8MHz interner Takt
 * 
 * Fuses for 8MHz internal clock:
 * avrdude -p m328p -c avrisp2 -U lfuse:w:0xe2:m 
 * avrdude -p m328p -c avrisp2 -U hfuse:w:0xd9:m 
 * 
 * avrdude -p m328p -c avrisp2
 * avrdude: Device signature = 0x1e950f             ; default output
 * avrdude: safemode: Fuses OK (E:07, H:D9, L:62)   ; default output
 * 
 * 
 * 
 * 
 * 
 * compile:
 * avr-gcc -Wall -Os -mmcu=atmega328p Pulses_095_prime.c -o Pulses_095_prime.elf
 * avr-objcopy -O ihex -j .text -j .data Pulses_095_prime.elf Pulses_095_prime.hex
 * avrdude -p m328p -c avrisp2 -U flash:w:Pulses_095_prime.hex
 * 
 * ---------------------------------------------------------------------------------------*/

#include <avr/io.h>
#include <avr/interrupt.h>


/* ------------ Variablen --------------------------*/

volatile uint8_t CLK_counter_11;			//  Impulszaehler
volatile uint8_t CLK_counter_13;
volatile uint8_t CLK_counter_17;
volatile uint8_t CLK_counter_19;
volatile uint8_t CLK_counter_23;
volatile uint8_t CLK_counter_29;
volatile uint8_t CLK_counter_31;
volatile uint8_t CLK_counter_37;

/* ---------------------------- Funktionen ------------------------------*/

//INT0 interrupt 
ISR(INT0_vect )                         //Clock in goes high
    
    { 
        CLK_counter_11++;                  // increase clock counter by rising edge
        CLK_counter_13++; 
        CLK_counter_17++; 
        CLK_counter_19++; 
        CLK_counter_23++; 
        CLK_counter_29++; 
        CLK_counter_31++; 
				CLK_counter_37++;
        
        
        if (CLK_counter_11 == 11)         // Divide by 11
        {
            PORTB = PORTB | 0b00000001;
	    CLK_counter_11 = 0;
        }
        
        if (CLK_counter_13 == 13)         // Divide by 13
        {
            PORTB =PORTB | 0b00000010;
	    CLK_counter_13 = 0;
        } 
        
        if (CLK_counter_17 == 17)         // Divide by 17
        {
            PORTB =PORTB | 0b00000100;
	    CLK_counter_17 = 0;
        } 
        
        if (CLK_counter_19 == 19)         // Divide by 19
        {
            PORTB =PORTB | 0b00001000;
	    CLK_counter_19 = 0;
        } 
        
         if (CLK_counter_23 == 23)         // Divide by 23
        {
            PORTB =PORTB | 0b00010000;
	    CLK_counter_23 = 0;
        } 
       
         if (CLK_counter_29 == 29)         // Divide by 29
        {
            PORTB =PORTB | 0b00100000;
	    CLK_counter_29 = 0;
        } 
        
         if (CLK_counter_31 == 31)         // Divide by 31
        {
            PORTB =PORTB | 0b01000000;
	    CLK_counter_31 = 0;
        } 
        
				 if (CLK_counter_37 == 37)         // Divide by 37
        {
            PORTB =PORTB | 0b10000000;
	    CLK_counter_37 = 0;
        } 
    } 

ISR(INT1_vect)              // Clock in goes low
{
    PORTB = 0b00000000;     // All outputs to zero
}
    
    

/* ----------------------MAIN ---------------------------*/
int main (void)
{
  DDRD &=~ (1 << PD3);									// set PD3 as input; INT0  
  DDRD &=~ (1 << PD2);									// set PD2 as input; INT1  
  PORTD |= (1 << PD2);
  DDRB = 0b11111111;										// PORTB output
  EIMSK |= (1<<INT0);										// enable INT0
  EIMSK |= (1<<INT1);										// enable INT1
  EICRA |= (1<<ISC00)|(1<<ISC01);       // INT0 - Rising edge on INT0 generates an interrupt request
  EICRA |= (1<<ISC11);                  // INT1 - Falling edge of INT1 generates interrupt request
  PORTB = 0b00000000;                   // All outputs to zero, 
  sei();			    									    // Interrupts aktivate
  while (1)                             // for ever
    {								
    }
}
